<?php
/**
 * Created by PhpStorm.
 * User: gets
 * Date: 4/4/2019
 * Time: 3:24 PM
 */

namespace App\Http\Controllers;

use App\Classes\MResponse;
use App\Http\Request\PackageKeyCreateRequest;
use App\Http\Request\PackageKeyActivateRequest;
use App\Http\Request\PackageKeyDisableRequest;
use App\Http\Request\PackageKeyDeleteRequest;
use App\Http\Request\PackageKeyGetByUserRequest;
use App\Http\Request\PackageKeyUpdatePlanRequest;

class PackageKeyController extends BaseController
{
    public function create(PackageKeyCreateRequest $request)
    {
        $mResponse = new MResponse();
        $statusCode = 200;

        $url = 'https://api.mashery.com/v3/rest/applications/' . $request->get('appId') . '/packageKeys'; 

        try {
            $response = $this->masheryClient()->request('POST', $url, [
                'json' => [
                    'apikey' => '',
                    'secret' => '',
                    'package' => [
                        'id' => $request->get('pkgId')
                    ],
                    'plan' => [
                        'id' => $request->get('planId')
                    ]
                ]
            ]);

            $resBody = json_decode($response->getBody()->getContents(), true);

            if ($response->getStatusCode() != 200) {
                $statusCode = $response->getStatusCode();
                $mResponse->message = $resBody;
            } else {
                $mResponse->success = true;
                $mResponse->message = 'success';
                $mResponse->data = $resBody;
            }
        } catch (\Exception $e) {
            $statusCode = 500;
            $mResponse->message = $e->getMessage();
        }

        return response()->json($mResponse, $statusCode);
    }

    public function activate(PackageKeyActivateRequest $request)
    {
        $mResponse = new MResponse();
        $statusCode = 200;
        
        $url = 'https://api.mashery.com/v3/rest/packageKeys/' . $request->get('pkgKeyId'); 

        try {
            $response = $this->masheryClient()->request('PUT', $url, [
                'json' => [
                    'status' => 'active'
                ]
            ]);

            $resBody = json_decode($response->getBody()->getContents(), true);

            if ($response->getStatusCode() != 200) {
                $statusCode = $response->getStatusCode();
                $mResponse->message = $resBody;
            } else {
                $mResponse->success = true;
                $mResponse->message = 'success';
                $mResponse->data = $resBody;
            }
        } catch (\Exception $e) {
            $statusCode = 500;
            $mResponse->message = $e->getMessage();
        }

        return response()->json($mResponse, $statusCode);
    }

    public function disable(PackageKeyDisableRequest $request)
    {
        $mResponse = new MResponse();
        $statusCode = 200;
        
        $url = 'https://api.mashery.com/v3/rest/packageKeys/' . $request->get('pkgKeyId'); 

        try {
            $response = $this->masheryClient()->request('PUT', $url, [
                'json' => [
                    'status' => 'disabled'
                ]
            ]);

            $resBody = json_decode($response->getBody()->getContents(), true);

            if ($response->getStatusCode() != 200) {
                $statusCode = $response->getStatusCode();
                $mResponse->message = $resBody;
            } else {
                $mResponse->success = true;
                $mResponse->message = 'success';
                $mResponse->data = $resBody;
            }
        } catch (\Exception $e) {
            $statusCode = 500;
            $mResponse->message = $e->getMessage();
        }

        return response()->json($mResponse, $statusCode);
    }

    public function delete(PackageKeyDeleteRequest $request)
    {
        $mResponse = new MResponse();
        $statusCode = 200;
        
        $url = 'https://api.mashery.com/v3/rest/applications/' . $request->get('appId') .'/packageKeys/' . $request->get('pkgKeyId'); 

        try {
            $response = $this->masheryClient()->request('DEL', $url);

            $resBody = json_decode($response->getBody()->getContents(), true);

            if ($response->getStatusCode() != 200) {
                $statusCode = $response->getStatusCode();
                $mResponse->message = $resBody;
            } else {
                $mResponse->success = true;
                $mResponse->message = 'success';
                $mResponse->data = $resBody;
            }
        } catch (\Exception $e) {
            $statusCode = 500;
            $mResponse->message = $e->getMessage();
        }

        return response()->json($mResponse, $statusCode);
    }

    public function getByUser(PackageKeyGetByUserRequest $request)
    {
        $mResponse = new MResponse();
        $statusCode = 200;
        
        $url = 'https://api.mashery.com/v3/rest/members/' . $request->get('userId') . '/packageKeys'; 

        try {
            $response = $this->masheryClient()->request('GET', $url, [
                'query' => [
                    'fields' => 'id,apikey,secret,status,application.id,application.name,application.username,package.id,package.name,plan.id,plan.name'
                ]
            ]);

            $resBody = json_decode($response->getBody()->getContents(), true);

            if ($response->getStatusCode() != 200) {
                $statusCode = $response->getStatusCode();
                $mResponse->message = $resBody;
            } else {
                $mResponse->success = true;
                $mResponse->message = 'success';
                $mResponse->data = $resBody;
            }
        } catch (\Exception $e) {
            $statusCode = 500;
            $mResponse->message = $e->getMessage();
        }

        return response()->json($mResponse, $statusCode);
    }

    public function updatePlan(PackageKeyUpdatePlanRequest $request)
    {
        $mResponse = new MResponse();
        $statusCode = 200;
        
        $url = 'https://api.mashery.com/v3/rest/applications/' . $request->get('appId') . '/packageKeys/' . $request->get('pkgKeyId'); 

        try {
            $response = $this->masheryClient()->request('PUT', $url, [
                'json' => [
                    'plan' => [
                        'id' => $request->get('planId')
                    ]
                ]
            ]);

            $resBody = json_decode($response->getBody()->getContents(), true);

            if ($response->getStatusCode() != 200) {
                $statusCode = $response->getStatusCode();
                $mResponse->message = $resBody;
            } else {
                $mResponse->success = true;
                $mResponse->message = 'success';
                $mResponse->data = $resBody;
            }
        } catch (\Exception $e) {
            $statusCode = 500;
            $mResponse->message = $e->getMessage();
        }

        return response()->json($mResponse, $statusCode);
    }
}
